@@ -1,6 +1,7 @@
 # !/usr/bin/env python3
 # encoding: utf-8
 from inspect import stack
+from typing import Awaitable
 
 apis = {('获取用户ID', 'get_bot_id'): [False, '此API不需要请求权限'],
         ('获取用户信息', 'get_bot_info'): ['GET', '/users/@me'],
@@ -68,7 +69,7 @@ apis = {('获取用户ID', 'get_bot_id'): [False, '此API不需要请求权限']
 
 
 def __getattr__(identifier: str) -> object:
-    if stack()[1].filename.split('\\')[-1] != 'qg_bot.py':
+    if stack()[1].filename.split('\\')[-1] not in ('qg_bot.py', 'api.py', 'async_api.py'):
         raise AssertionError("此为SDK内部使用文件，无法使用，使用机器人Model库请from model import Model")
 
     return globals()[identifier.__path__]
@@ -92,7 +93,7 @@ def api_converter_re(method: str, path: str):
 
 class ReplyModel:
     def __init__(self, type_: object or dict = object):
-        if stack()[1].filename.split('\\')[-1] != 'qg_bot.py':
+        if stack()[1].filename.split('\\')[-1] not in ('qg_bot.py', 'api.py', 'async_api.py'):
             raise AssertionError('ReplyModel()为SDK内部使用类，无法使用')
         self.type_ = type_
 
